@@ -270,11 +270,11 @@ def extract_wasDerivedFrom(metadata):
 
 
 extract_wasAttributedTo = extract_model_list(
-    models.Participant, "identifier", "subject_id"
+    models.Participant, "identifier", "subject_id", id=...
 )
 
 extract_wasGeneratedBy = extract_model_list(
-    models.Session, "name", "session_id", identifier=None
+    models.Session, "name", "session_id", id=...
 )
 
 
@@ -358,7 +358,7 @@ def get_default_metadata(path, digest=None, digest_type=None) -> models.BareAsse
 
 def get_generator(start_time: datetime, end_time: datetime) -> models.Activity:
     return models.Activity(
-        identifier=str(uuid4()),
+        id=uuid4().urn,
         name="Metadata generation",
         description="Metadata generated by DANDI cli",
         wasAssociatedWith=[
@@ -483,7 +483,10 @@ def convertv1(data):
             ]
         if oldkey == "license":
             value = [
-                getattr(models.LicenseType, value.replace("-", "").replace(".", ""))
+                getattr(
+                    models.LicenseType,
+                    value.replace("dandi", "spdx").replace("-", "_").replace(".", ""),
+                )
             ]
         if oldkey == "identifier":
             value = f"DANDI:{value}"
@@ -603,6 +606,10 @@ def convertv1(data):
 
 def migrate2newschema(meta):
     newmeta = convertv1(meta)
+    if "version" in newmeta:
+        newmeta["id"] = f"{newmeta['identifier']}/{newmeta['version']}"
+    else:
+        newmeta["id"] = f"{newmeta['identifier']}/draft"
     dandimeta = models.DandisetMeta.unvalidated(**newmeta)
     return dandimeta
 
@@ -613,6 +620,7 @@ def generate_context():
     fields = {
         "@version": 1.1,
         "dandi": "http://schema.dandiarchive.org/",
+        "dandiasset": "http://iri.dandiarchive.org/",
         "DANDI": "http://identifiers.org/DANDI:",
         "dct": "http://purl.org/dc/terms/",
         "owl": "http://www.w3.org/2002/07/owl#",
@@ -631,6 +639,7 @@ def generate_context():
         "ORCID": "https://orcid.org/",
         "ROR": "https://ror.org/",
         "PATO": "http://purl.obolibrary.org/obo/PATO_",
+        "spdx": "http://spdx.org/licenses/",
     }
     for val in dir(models):
         klass = getattr(models, val)
@@ -641,7 +650,7 @@ def generate_context():
                 name = klass.__name__
                 fields[name] = f'{klass._ldmeta["nskey"]}:{name}'
         for name, field in klass.__fields__.items():
-            if name == "identifier":
+            if name == "id":
                 fields[name] = "@id"
             elif name == "schemaKey":
                 fields[name] = "@type"
